==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiWidgets/QGraphicsTextItem_shell.h <==
#ifndef QGRAPHICSTEXTITEM_SHELL_H
#define QGRAPHICSTEXTITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#include <QtJambi/QtJambiAPI>
#include <QTextCursor>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcolor.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtransform.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicssceneevent.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicstransform.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(graphicsview)

class QGraphicsTextItem_shell : public QGraphicsTextItem, public QtJambiShellInterface
{
public:
    QGraphicsTextItem_shell(QGraphicsItem* parent0 = nullptr);
    QGraphicsTextItem_shell(const QString& text0, QGraphicsItem* parent1 = nullptr);
    ~QGraphicsTextItem_shell() override;

    void advance(int phase0) override;
    QRectF boundingRect() const override;
    void childEvent(QChildEvent* event0) override;
    bool collidesWithItem(const QGraphicsItem* other0, Qt::ItemSelectionMode mode1) const override;
    bool collidesWithPath(const QPainterPath& path0, Qt::ItemSelectionMode mode1) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragLeaveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragMoveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dropEvent(QGraphicsSceneDragDropEvent* event0) override;
    bool event(QEvent* ev0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QVariant extension(const QVariant& variant0) const override;
    void focusInEvent(QFocusEvent* event0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    void hoverEnterEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverMoveEvent(QGraphicsSceneHoverEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isObscuredBy(const QGraphicsItem* item0) const override;
    QVariant itemChange(QGraphicsItem::GraphicsItemChange change0, const QVariant& value1) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event0) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event0) override;
    QPainterPath opaqueArea() const override;
    void paint(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    bool sceneEvent(QEvent* event0) override;
    bool sceneEventFilter(QGraphicsItem* watched0, QEvent* event1) override;
    void setExtension(QGraphicsItem::Extension extension0, const QVariant& variant1) override;
    QPainterPath shape() const override;
    bool supportsExtension(QGraphicsItem::Extension extension0) const override;
    void timerEvent(QTimerEvent* event0) override;
    void wheelEvent(QGraphicsSceneWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsTextItem_access : public QGraphicsTextItem
{
    jobject __qt_boundingRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_contains_cref_QPointF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID point0) const;
    void __qt_contextMenuEvent_QGraphicsSceneContextMenuEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragEnterEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragLeaveEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragMoveEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dropEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_extension_cref_QVariant_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject variant0) const;
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverEnterEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverLeaveEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverMoveEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_inputMethodEvent_QInputMethodEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_inputMethodQuery_Qt_InputMethodQuery_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint query0) const;
    jboolean __qt_isObscuredBy_const_QGraphicsItem_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0) const;
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_keyReleaseEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseDoubleClickEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseMoveEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mousePressEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseReleaseEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_opaqueArea(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_paint_QPainter_ptr_const_QStyleOptionGraphicsItem_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID widget2);
    jboolean __qt_sceneEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_setExtension_QGraphicsItem_Extension_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint extension0, jobject variant1);
    jobject __qt_shape(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_supportsExtension_QGraphicsItem_Extension_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint extension0) const;
};

#endif // QT_CONFIG(graphicsview)
#endif // QGRAPHICSTEXTITEM_SHELL_H

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QGraphicsTextItem_shell.h <==
#ifndef QGRAPHICSTEXTITEM_SHELL_H
#define QGRAPHICSTEXTITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#include <QtJambi/QtJambiAPI>
#include <QTextCursor>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcolor.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtransform.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsscene.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicssceneevent.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicstransform.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(graphicsview)

class QGraphicsTextItem_shell : public QGraphicsTextItem, public QtJambiShellInterface
{
public:
    QGraphicsTextItem_shell(QGraphicsItem* parent0 = nullptr);
    QGraphicsTextItem_shell(const QString& text0, QGraphicsItem* parent1 = nullptr);
    ~QGraphicsTextItem_shell() override;

    void advance(int phase0) override;
    QRectF boundingRect() const override;
    void childEvent(QChildEvent* event0) override;
    bool collidesWithItem(const QGraphicsItem* other0, Qt::ItemSelectionMode mode1) const override;
    bool collidesWithPath(const QPainterPath& path0, Qt::ItemSelectionMode mode1) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragLeaveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dragMoveEvent(QGraphicsSceneDragDropEvent* event0) override;
    void dropEvent(QGraphicsSceneDragDropEvent* event0) override;
    bool event(QEvent* ev0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QVariant extension(const QVariant& variant0) const override;
    void focusInEvent(QFocusEvent* event0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    void hoverEnterEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverLeaveEvent(QGraphicsSceneHoverEvent* event0) override;
    void hoverMoveEvent(QGraphicsSceneHoverEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* event0) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isObscuredBy(const QGraphicsItem* item0) const override;
    QVariant itemChange(QGraphicsItem::GraphicsItemChange change0, const QVariant& value1) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event0) override;
    void mousePressEvent(QGraphicsSceneMouseEvent* event0) override;
    void mouseReleaseEvent(QGraphicsSceneMouseEvent* event0) override;
    QPainterPath opaqueArea() const override;
    void paint(QPainter* painter0, const QStyleOptionGraphicsItem* option1, QWidget* widget2) override;
    bool sceneEvent(QEvent* event0) override;
    bool sceneEventFilter(QGraphicsItem* watched0, QEvent* event1) override;
    void setExtension(QGraphicsItem::Extension extension0, const QVariant& variant1) override;
    QPainterPath shape() const override;
    bool supportsExtension(QGraphicsItem::Extension extension0) const override;
    void timerEvent(QTimerEvent* event0) override;
    void wheelEvent(QGraphicsSceneWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsTextItem_access : public QGraphicsTextItem
{
    jobject __qt_boundingRect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_contains_cref_QPointF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID point0) const;
    void __qt_contextMenuEvent_QGraphicsSceneContextMenuEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragEnterEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragLeaveEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dragMoveEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_dropEvent_QGraphicsSceneDragDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_extension_cref_QVariant_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject variant0) const;
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverEnterEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverLeaveEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_hoverMoveEvent_QGraphicsSceneHoverEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_inputMethodEvent_QInputMethodEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_inputMethodQuery_Qt_InputMethodQuery_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint query0) const;
    jboolean __qt_isObscuredBy_const_QGraphicsItem_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0) const;
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_keyReleaseEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseDoubleClickEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseMoveEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mousePressEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_mouseReleaseEvent_QGraphicsSceneMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_opaqueArea_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_paint_QPainter_ptr_const_QStyleOptionGraphicsItem_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID widget2);
    jboolean __qt_sceneEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_setExtension_QGraphicsItem_Extension_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint extension0, jobject variant1);
    jobject __qt_shape_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_supportsExtension_QGraphicsItem_Extension_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint extension0) const;
};

#endif // QT_CONFIG(graphicsview)
#endif // QGRAPHICSTEXTITEM_SHELL_H
